Skip to contents

Calculate metabolic reaction scores (MRAS) for 13082 reactions

Usage

calculate_reaction_score(data)

Arguments

data

gene expression data.1.The gene expression matrix should be gene by sample matrix where row names are human gene names (gene symbols), and column names should be sample names. Please note that METAFLUX does not support other gene IDs. 2.The input gene expression matrix should be normalized (e.g., log-transformed, etc.) before using METAFLUX. METAFLUX will not perform any normalization on expression data. 3.Gene expression data cannot have negative values.