Skip to contents

This default file indicates the nutrients available in the medium. There are total 44 metabolites available. This file can be changed depending on users. We will allow users to define the medium profile based on their knowledge.

Usage

human_blood

Format

A data frame with 44 rows and 2 variables:

metabolite

stands for name of nutrients available in the human blood.

reaction_name

tands for reaction ID of corresponding nutreints

Examples

data(human_blood)