This default file indicates the nutrients available in the medium. There are total 44 metabolites available. This file can be changed depending on users. We will allow users to define the medium profile based on their knowledge.
Format
A data frame with 44 rows and 2 variables:
- metabolite
stands for name of nutrients available in the medium.
- reaction_name
V2 stands for reaction ID of corresponding nutreints
Examples
data(cell_medium)